@@ -4,7 +4,8 @@ use strict;
 use warnings FATAL => 'all';
 use base qw(Exporter);
 
-our $VERSION = '1.002006';
+our $VERSION = '1.003001';
+$VERSION = eval $VERSION;
 
 sub _choose_json_module {
     return 'Cpanel::JSON::XS' if $INC{'Cpanel/JSON/XS.pm'};
@@ -31,8 +32,11 @@ BEGIN {
 }
 
 our @EXPORT = qw(encode_json decode_json JSON);
-our @EXPORT_OK = qw(is_bool);
-our %EXPORT_TAGS = ( all => [ @EXPORT, @EXPORT_OK ] );
+my @EXPORT_ALL = qw(is_bool);
+our @EXPORT_OK = qw(is_bool to_json from_json);
+our %EXPORT_TAGS = ( all => [ @EXPORT, @EXPORT_ALL ],
+                     legacy => [ @EXPORT, @EXPORT_OK ],
+                   );
 
 sub JSON () { our $JSON_Class }
 
@@ -51,9 +55,48 @@ sub is_bool {
 
   Scalar::Util::blessed($_[0])
     and ($_[0]->isa('JSON::XS::Boolean')
+      or $_[0]->isa('Cpanel::JSON::PP::Boolean')
       or $_[0]->isa('JSON::PP::Boolean'));
 }
 
+# (mostly) CopyPasta from JSON.pm version 2.90
+use Carp ();
+
+sub from_json ($@) {
+    if ( ref($_[0]) =~ /^JSON/ or $_[0] =~ /^JSON/ ) {
+        Carp::croak "from_json should not be called as a method.";
+    }
+    my $json = JSON()->new;
+
+    if (@_ == 2 and ref $_[1] eq 'HASH') {
+        my $opt  = $_[1];
+        for my $method (keys %$opt) {
+            $json->$method( $opt->{$method} );
+        }
+    }
+
+    return $json->decode( $_[0] );
+}
+
+sub to_json ($@) {
+    if (
+        ref($_[0]) =~ /^JSON/
+        or (@_ > 2 and $_[0] =~ /^JSON/)
+          ) {
+               Carp::croak "to_json should not be called as a method.";
+    }
+    my $json = JSON()->new;
+
+    if (@_ == 2 and ref $_[1] eq 'HASH') {
+        my $opt  = $_[1];
+        for my $method (keys %$opt) {
+            $json->$method( $opt->{$method} );
+        }
+    }
+
+    $json->encode($_[0]);
+}
+
 1;
 
 =head1 NAME
@@ -98,10 +141,22 @@ To import only some symbols, specify them on the C<use> line:
 
   use JSON::MaybeXS qw(JSON); # JSON constant only
 
-To import all available symbols, use C<:all>:
+To import all available sensible symbols (C<encode_json>, C<decode_json>, and
+C<is_bool>), use C<:all>:
 
   use JSON::MaybeXS ':all';
 
+To import all symbols including those needed by legacy apps that use L<JSON::PP>:
+
+  use JSON::MaybeXS ':legacy';
+
+This imports the C<to_json> and C<from_json> symbols as well as everything in
+C<:all>.  NOTE: This is to support legacy code that makes extensive
+use of C<to_json> and C<from_json> which you are not yet in a position to
+refactor.  DO NOT use this import tag in new code, in order to avoid
+the crawling horrors of getting UTF8 support subtly wrong.  See the
+documentation for L<JSON> for further details.
+
 =head2 encode_json
 
 This is the C<encode_json> function provided by the selected implementation
@@ -116,6 +171,11 @@ module, and takes a string of JSON text to deserialise to a perl data structure.
 
   my $data_structure = decode_json($json_text);
 
+=head2 to_json, from_json
+
+See L<JSON> for details.  These are included to support legacy code
+B<only>.
+
 =head2 JSON
 
 The C<JSON> constant returns the selected implementation module's name for
@@ -175,6 +235,8 @@ mst - Matt S. Trout (cpan:MSTROUT) <mst@shadowcat.co.uk>
 
 =item * Karen Etheridge <ether@cpan.org>
 
+=item * Kieren Diment <diment@gmail.com>
+
 =back
 
 =head1 COPYRIGHT
